# -*- coding: utf-8 -*-

"""Top-level package for brownpaperbag."""

__author__ = """Bruno Paulin"""
__email__ = "brunopaulin@bpaulin.net"
__version__ = "2.0.1"

# flake8: noqa
from .bpbgate import BpbCommandSession, BpbEventSession
